==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebRowExportingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowExportingEventArgsDetailDescription } from "./WebRowExportingEventArgsDetailDescription";
/**
 * @hidden
 */
var WebRowExportingEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowExportingEventArgsDetailDescriptionMetadata, _super);
    function WebRowExportingEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowExportingEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebRowExportingEventArgsDetailDescriptionMetadata.a == null) {
            WebRowExportingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowExportingEventArgsDetailDescriptionMetadata.c(WebRowExportingEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebRowExportingEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebRowExportingEventArgsDetailDescriptionMetadata.a);
    };
    WebRowExportingEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:RowExportingEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("RowData", "Unknown");
        a.item("RowIndex", "Number:double");
        a.item("Cancel", "Boolean");
    };
    WebRowExportingEventArgsDetailDescriptionMetadata.d = function (a) {
        WebRowExportingEventArgsDetailDescriptionMetadata.b(a);
        a.ad("WebRowExportingEventArgsDetail", function () { return new WebRowExportingEventArgsDetailDescription(); });
        a.ac("WebRowExportingEventArgsDetail", WebRowExportingEventArgsDetailDescriptionMetadata.a);
    };
    WebRowExportingEventArgsDetailDescriptionMetadata.$t = markType(WebRowExportingEventArgsDetailDescriptionMetadata, 'WebRowExportingEventArgsDetailDescriptionMetadata');
    WebRowExportingEventArgsDetailDescriptionMetadata.a = null;
    return WebRowExportingEventArgsDetailDescriptionMetadata;
}(Base));
export { WebRowExportingEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebRowExportingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowExportingEventArgsDetailDescription } from "./WebRowExportingEventArgsDetailDescription";
/**
 * @hidden
 */
var WebRowExportingEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRowExportingEventArgsDetailDescriptionMetadata, _super);
    function WebRowExportingEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRowExportingEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebRowExportingEventArgsDetailDescriptionMetadata.a == null) {
            WebRowExportingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRowExportingEventArgsDetailDescriptionMetadata.c(WebRowExportingEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebRowExportingEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebRowExportingEventArgsDetailDescriptionMetadata.a);
    };
    WebRowExportingEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:RowExportingEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("RowData", "Unknown");
        a.item("RowIndex", "Number:double");
        a.item("Cancel", "Boolean");
    };
    WebRowExportingEventArgsDetailDescriptionMetadata.d = function (a) {
        WebRowExportingEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebRowExportingEventArgsDetail", function () { return new WebRowExportingEventArgsDetailDescription(); });
        a.ad("WebRowExportingEventArgsDetail", WebRowExportingEventArgsDetailDescriptionMetadata.a);
    };
    WebRowExportingEventArgsDetailDescriptionMetadata.$t = markType(WebRowExportingEventArgsDetailDescriptionMetadata, 'WebRowExportingEventArgsDetailDescriptionMetadata');
    WebRowExportingEventArgsDetailDescriptionMetadata.a = null;
    return WebRowExportingEventArgsDetailDescriptionMetadata;
}(Base));
export { WebRowExportingEventArgsDetailDescriptionMetadata };
